@@ -546,8 +546,11 @@ p_hsLocalBinds = \case
     -- of p_hsLocalBinds). Hence, we introduce a manual Located as we
     -- depend on the layout being correctly set.
     pseudoLocated = \case
-      EpAnn {anns = AnnList {al_anchor = Just Anchor {anchor}}} ->
-        located (L (RealSrcSpan anchor Strict.Nothing) ()) . const
+      EpAnn {anns = AnnList {al_anchor = Just Anchor {anchor}}}
+        | let sp = RealSrcSpan anchor Strict.Nothing,
+          -- excluding cases where there are no bindings
+          not $ isZeroWidthSpan sp ->
+            located (L sp ()) . const
       _ -> id
 
 p_ldotFieldOcc :: XRec GhcPs (DotFieldOcc GhcPs) -> R ()
@@ -1049,8 +1052,14 @@ p_let' inDo letLoc localBinds mBody = do
           LetInline -> True
           LetNewline -> False
           LetMixed -> numLocalBinds <= 1
-  -- isInShifted = True if "in" should be right-aligned with "let"
-  let isInShifted = inDo || inStyle == InRightAlign
+  let inString =
+        case inStyle of
+          _ | inDo -> " in"
+          InRightAlign -> " in"
+          InLeftAlign
+            | isBlockInline -> "in "
+            | otherwise -> "in"
+          InNoSpace -> "in"
 
   -- helpers
   let block keyword body = do
@@ -1069,11 +1078,7 @@ p_let' inDo letLoc localBinds mBody = do
             block "in" body
         | otherwise -> do
             newline
-            let in_
-                  | isInShifted = " in"
-                  | isBlockInline = "in "
-                  | otherwise = "in"
-            block in_ body
+            block inString body
       Nothing -> pure ()
   where
     numLocalBinds =
@@ -1258,7 +1263,7 @@ p_hsQuote epAnn = \case
     -- of an (*|) operator.
     -- The detection is a bit overcautious, as it adds the spaces as soon as
     -- HsStarTy is anywhere in the type/declaration.
-    handleStarIsType :: Data a => a -> R () -> R ()
+    handleStarIsType :: (Data a) => a -> R () -> R ()
     handleStarIsType a p
       | containsHsStarTy a = space *> p <* space
       | otherwise = p
@@ -1324,7 +1329,7 @@ layoutToBraces = \case
 
 -- | Append each element in both lists with semigroups. If one list is shorter
 -- than the other, return the rest of the longer list unchanged.
-liftAppend :: Semigroup a => [a] -> [a] -> [a]
+liftAppend :: (Semigroup a) => [a] -> [a] -> [a]
 liftAppend [] [] = []
 liftAppend [] (y : ys) = y : ys
 liftAppend (x : xs) [] = x : xs
